"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const image_size_1 = __importDefault(require("image-size"));
const filesize_1 = __importDefault(require("filesize"));
const fs_1 = require("./fs");
const optimize_1 = require("./optimize");
const generate_1 = require("./generate");
async function parseInput(filename) {
    const { width, height, type } = image_size_1.default(filename);
    const size = filesize_1.default((await fs_1.stat(filename)).size);
    return { size, type, filename, width, height };
}
async function default_1(filename, numberOfPrimitives, blur = 0, mode = 0 /* Combo */, optimize = true) {
    const input = await parseInput(filename);
    const { width, height } = input;
    const options = {
        mode,
        blur,
        numberOfPrimitives,
        width,
        height,
        filename
    };
    const output = generate_1.generateSVG(options);
    if (optimize) {
        const optimized = await optimize_1.optimizeSVG(output.svg);
        output.svgSize = filesize_1.default(optimized.length);
        output.svg = optimized;
    }
    return {
        input,
        output
    };
}
exports.default = default_1;
//# sourceMappingURL=index.js.map